==> qore-0.8.11.1.tar.bz2: qore-0.8.11.1/include/qore/intern/ExecArgList.h <==
/* -*- mode: c++; indent-tabs-mode: nil -*- */
/*
  ExecArgList.h
 
  Qore Programming Language
 
  Copyright (C) 2003 - 2014 David Nichols
 
  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation
  the rights to use, copy, modify, merge, publish, distribute, sublicense,
  and/or sell copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.

  Note that the Qore library is released under a choice of three open-source
  licenses: MIT (as above), LGPL 2+, or GPL 2+; see README-LICENSE for more
  information.
*/

#ifndef _QORE_EXECARGLIST_H

#define _QORE_EXECARGLIST_H

class ExecArgList {
private:
   char **arg;
   int allocated;
   int len;

   DLLLOCAL char *getString(const char *start, int size);
   DLLLOCAL void addArg(char *str);

public:
   DLLLOCAL ExecArgList(const char *str);
   DLLLOCAL ~ExecArgList();
   DLLLOCAL char *getFile();
   DLLLOCAL char **getArgs();
#ifdef DEBUG
   DLLLOCAL void showArgs();
#endif
};

#endif

==> qore-0.8.13.2.tar.bz2: qore-0.8.13.2/include/qore/intern/ExecArgList.h <==
/* -*- mode: c++; indent-tabs-mode: nil -*- */
/*
  ExecArgList.h

  Qore Programming Language

  Copyright (C) 2003 - 2015 David Nichols

  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation
  the rights to use, copy, modify, merge, publish, distribute, sublicense,
  and/or sell copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.

  Note that the Qore library is released under a choice of three open-source
  licenses: MIT (as above), LGPL 2+, or GPL 2+; see README-LICENSE for more
  information.
*/

#ifndef _QORE_EXECARGLIST_H

#define _QORE_EXECARGLIST_H

class ExecArgList {
private:
   char** arg;
   int allocated;
   int len;

   DLLLOCAL char* getString(const char* start, int size);
   DLLLOCAL void addArgIntern(char* str);

public:
   DLLLOCAL ExecArgList();
   DLLLOCAL ExecArgList(const char* str);
   DLLLOCAL ~ExecArgList();

   DLLLOCAL void addArg(const char* str);
   DLLLOCAL char* getFile();
   DLLLOCAL char** getArgs();
#ifdef DEBUG
   DLLLOCAL void showArgs();
#endif
};

#endif
